==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebBadgeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBadgeDescription } from "./WebBadgeDescription";
/**
 * @hidden
 */
var WebBadgeDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebBadgeDescriptionMetadata, _super);
    function WebBadgeDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebBadgeDescriptionMetadata.b = function (a) {
        if (WebBadgeDescriptionMetadata.a == null) {
            WebBadgeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebBadgeDescriptionMetadata.c(WebBadgeDescriptionMetadata.a);
        }
        if (a.j(WebBadgeDescriptionMetadata.a)) {
            return;
        }
        a.y(WebBadgeDescriptionMetadata.a);
    };
    WebBadgeDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Badge");
        a.item("__tagNameWC", "String:igc-badge");
        a.item("Variant", "ExportedType:string:BadgeVariant");
        a.item("Variant@names", "Primary;Info;Success;Warning;Danger");
        a.item("Outlined", "Boolean");
        a.item("Shape", "ExportedType:string:BadgeShape");
        a.item("Shape@names", "Rounded;Square");
    };
    WebBadgeDescriptionMetadata.d = function (a) {
        WebBadgeDescriptionMetadata.b(a);
        a.aa("WebBadge", function () { return new WebBadgeDescription(); });
        a.z("WebBadge", WebBadgeDescriptionMetadata.a);
    };
    WebBadgeDescriptionMetadata.$t = markType(WebBadgeDescriptionMetadata, 'WebBadgeDescriptionMetadata');
    WebBadgeDescriptionMetadata.a = null;
    return WebBadgeDescriptionMetadata;
}(Base));
export { WebBadgeDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebBadgeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBadgeDescription } from "./WebBadgeDescription";
/**
 * @hidden
 */
var WebBadgeDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebBadgeDescriptionMetadata, _super);
    function WebBadgeDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebBadgeDescriptionMetadata.b = function (a) {
        if (WebBadgeDescriptionMetadata.a == null) {
            WebBadgeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebBadgeDescriptionMetadata.c(WebBadgeDescriptionMetadata.a);
        }
        if (a.k(WebBadgeDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebBadgeDescriptionMetadata.a);
    };
    WebBadgeDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Badge");
        a.item("__tagNameWC", "String:igc-badge");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Variant", "ExportedType:string:BadgeVariant");
        a.item("Variant@stringUnion", "WebComponents;React");
        a.item("Variant@names", "Primary;Info;Success;Warning;Danger");
        a.item("Outlined", "Boolean");
        a.item("Shape", "ExportedType:string:BadgeShape");
        a.item("Shape@stringUnion", "WebComponents;React");
        a.item("Shape@names", "Rounded;Square");
    };
    WebBadgeDescriptionMetadata.d = function (a) {
        WebBadgeDescriptionMetadata.b(a);
        a.ac("WebBadge", function () { return new WebBadgeDescription(); });
        a.ab("WebBadge", WebBadgeDescriptionMetadata.a);
    };
    WebBadgeDescriptionMetadata.$t = markType(WebBadgeDescriptionMetadata, 'WebBadgeDescriptionMetadata');
    WebBadgeDescriptionMetadata.a = null;
    return WebBadgeDescriptionMetadata;
}(Base));
export { WebBadgeDescriptionMetadata };
